import { Provide } from '@midwayjs/core';
import { InjectEntityModel } from '@midwayjs/typeorm';
import { Repository } from 'typeorm';
import { User } from '../entity/user.entity';
import hash from 'object-hash';

@Provide()
export class UserService {
  @InjectEntityModel(User)
  userModel: Repository<User>;

  async select(p: User): Promise<User> {
    const { user_login } = p;
    const user = await this.userModel.findOne({
      where: { user_login },
    });
    return user;
  }

  async selectAll(): Promise<User[]> {
    return await this.userModel.find();
  }

  async createUser(user: User) {
    const h = hash('' + user.user_login);
    user.display_name = h.substring(0, 8);
    user.user_avatar = h;
    const result = await this.userModel.save(user);
    return result;
  }

  async update(user: User) {
    this.userModel.save(user);
  }
}
