import axios from "axios";
import Cookies from "js-cookie";
import toast from "react-hot-toast";
import { removeLoginCookies } from "../util/cookie";

const config = {
  baseURL: "",
  timeout: 1000 * 15,
  headers: {},
};

export const instance = axios.create(config);

instance.interceptors.request.use(
  (config) => {
    return config;
  },
  (error) => {
    return Promise.reject(error);
  }
);

// Add a response interceptor
instance.interceptors.response.use(
  (response) => {
    // midwayjs校验
    if ("success" in response.data) {
      const { success, message } = response.data;
      if (!success) return console.error(message);
    }
    // 业务校验
    const { msg, code } = response.data;
    switch (code) {
      case 10000:
        // Message.success(`接口: ${response.config.url}, 请求成功`);
        break;
      case 20000:
        // Message.error(`接口: ${response.config.url}, 遇到错误`);
        break;
      case 40000:
        toast.error(msg);
        break;
      case 50000:
        toast.error(msg);
        removeLoginCookies();
        break;
      default:
        // TODO ...
        break;
    }
    return response?.data;
  },
  (error) => {
    return Promise.reject(error);
  }
);

export default instance;
