import { AxiosInstance, AxiosRequestConfig, AxiosResponse } from "axios";
import { useEffect, useState } from "react";
import { instance } from "../api/axios";
import toast from "react-hot-toast";

interface IProps {
  axiosInstance?: AxiosInstance;
  method?: "get" | "post" | "put" | "delete";
  url: string;
  requestConfig?: AxiosRequestConfig;
}

export const useAxios = (props: IProps) => {
  const [response, setResponse] = useState<AxiosResponse<any, any>>();
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<unknown>();
  const {
    axiosInstance = instance,
    method = "post",
    url,
    requestConfig = {},
  } = props;

  useEffect(() => {
    const controller = new AbortController();
    const fetchData = async () => {
      try {
        const res = await axiosInstance[method](url, {
          ...requestConfig,
          signal: controller.signal,
        });
        setResponse(res);
      } catch (error) {
        setError(error);
      } finally {
        setLoading(false);
      }
    };
    fetchData();
    return controller.abort();
  }, []);

  return [response, loading, error];
};
