import { useEffect } from "react";
import { useLocation, useNavigate } from "react-router-dom";
import { useUserStore } from "../store/user.store";
import Result from "../components/Result";
import { withLoginCookies } from "../util/cookie";

interface IGuardProps {
  children: JSX.Element;
}

const needAuthList = ["course/detail"];

export const Guard = (props: IGuardProps) => {
  const navigate = useNavigate();
  const user = useUserStore((s: any) => s.user);
  const fetchUser = useUserStore((s: any) => s.fetchUser);

  const location = useLocation();
  const needAuth = needAuthList.some((p) => location.pathname.indexOf(p) > -1);

  useEffect(() => {
    if (!user) fetchUser();
  }, [location.pathname]);

  if (!withLoginCookies() && needAuth) return <Result code={405} />;

  return props.children;
};
