import { useEffect, useState } from "react";
import ReactMarkdown from "react-markdown";
import remarkGfm from "remark-gfm";

interface IProps {
  mdText: string;
}

function Guide(props: IProps) {
  const [md, setMD] = useState<string>("");

  useEffect(() => {
    if (props.mdText) setMD(props.mdText);
  }, [props.mdText]);

  return (
    <div
      style={{
        maxWidth: 1120,
        margin: "0 auto",
        overflow: "hidden",
        padding: "0 24px",
      }}
    >
      <ReactMarkdown
        children={md}
        remarkPlugins={[remarkGfm]}
        components={{
          code({ node, inline, className, children, ...props }) {
            return !inline ? (
              <code className={`${className} bs code`} {...props}>
                {children}
              </code>
            ) : (
              <code className={className} {...props}>
                {children}
              </code>
            );
            // return !inline && match ? (
            //   <SyntaxHighlighter
            //     children={String(children).replace(/\n$/, "")}
            //     style={atomDark}
            //     showLineNumbers
            //     language={match[1]}
            //     PreTag="div"
            //     // {...props}
            //   />
            // ) : (
            //   <code className={className} {...props}>
            //     {children}
            //   </code>
            // );
          },
        }}
        className="markdown-body"
      />
    </div>
  );
}

export default Guide;
