import { useEffect, useState } from "react";
import "./index.less";
import Guide from "./components/Guide";
import { useMount } from "../../hook";
import Player from "./components/DPlayer";
import { useParams } from "react-router-dom";
import { getCourseDetailById } from "../../api";
import { ms2Time } from "./util";
import Result from "../../components/Result";
import PlayCircle20Regular from "@ricons/fluent/PlayCircle20Regular";
import DocumentChevronDouble20Regular from "@ricons/fluent/DocumentChevronDouble20Regular";
import { Icon } from "@ricons/utils";
import dayjs from "dayjs";
import { IChapter } from "../../api/dto";

interface IState {
  toc: any[];
  course: {
    course_title: string;
    course_createtime: string;
  };
  view: JSX.Element | null;
}

const defaultState = {
  toc: [],
  course: {
    course_title: "",
    course_createtime: "",
  },
  view: null,
};

function CourseDetail() {
  const { id: course_id = "" } = useParams();
  const [state, setState] = useState<IState>(defaultState);

  const chapters2toc = (chapterList: IChapter[]) => {
    return chapterList.map((item) => {
      return {
        title: item.chapter_title,
        level: +item.chapter_level!,
        time: ms2Time(+item.media_time!),
        icon: !!item.media_url ? (
          <Icon size={20}>
            <PlayCircle20Regular />
          </Icon>
        ) : null,
        active: false,
        view: (
          <Player
            video={{ url: item.media_url!, pic: item.media_cover_url! }}
          />
        ),
      };
    });
  };

  const computeYMD = (ts: number) => dayjs(ts).format("YYYY-MM-DD");

  useMount(() => {
    if (!!course_id)
      getCourseDetailById(course_id).then((res: any) => {
        const { data = [], code } = res;
        switch (code) {
          case 50000:
            setState((p) => ({ ...p, view: <Result code={403} /> }));
            break;
          case 10000:
            const { chapterList = [], course, guide } = data;
            const course_createtime = computeYMD(+course.course_createtime);
            setState({
              course: { ...course, course_createtime },
              toc: [
                {
                  title: "导读",
                  level: 1,
                  time: "",
                },
                {
                  title: "介绍 / 下载",
                  level: 2,
                  time: "",
                  active: true,
                  icon: (
                    <Icon size={20}>
                      <DocumentChevronDouble20Regular />
                    </Icon>
                  ),
                  view: <Guide mdText={guide.guide_html} />,
                },
                ...chapters2toc(chapterList),
              ],
              view: <Guide mdText={data?.guide.guide_value} />,
            });
          default:
            break;
        }
      });
  });

  const onclickItem = (i: any) => {
    setState((p) => ({
      ...p,
      toc: p.toc.map((p: any) => ({ ...p, active: i.title === p.title })),
      view: i.view ?? <Result code={404} />,
    }));
  };

  return (
    <div className="course-detail">
      {state.toc.length > 0 ? (
        <>
          <aside className="table-of-content">
            <h3>{state.course.course_title}</h3>
            <div style={{ color: "var(--color-text-3)", fontSize: 13 }}>
              <span>{state.course.course_createtime}</span>
            </div>
            <div className="toc">
              {state.toc.map((i: any) => {
                if (i.level === 1) {
                  return (
                    <div className="level-1" key={i.title}>
                      {i.title}
                    </div>
                  );
                } else if (i.level === 2) {
                  return (
                    <div
                      className={`level-2 ${i.active ? "active" : ""}`}
                      key={i.title}
                      onClick={() => onclickItem(i)}
                    >
                      <div className="bs fc">
                        {i.icon}
                        <span style={{ padding: "0 12px 0 6px" }}>
                          {i.title}
                        </span>
                      </div>
                      <span className="time">{i.time}</span>
                    </div>
                  );
                }
              })}
            </div>
          </aside>
          <div
            className="content"
            style={{ left: state.toc.length > 0 ? 300 : "0" }}
          >
            {state.view}
          </div>
        </>
      ) : (
        <Result code={403} />
      )}
    </div>
  );
}

export default CourseDetail;
